@@ -1,6 +1,19 @@
 import numpy as np
-from PIL import Image
+from PIL import Image, ImageSequence
 import requests
+from io import BytesIO
+
+
+def read_frame(file_path):
+    im = Image.open(file_path)
+    imgs = [frame.copy() for frame in ImageSequence.Iterator(im)]
+    return imgs[1:]
+
+
+def read_frame_from_bytes(image_bytes):
+    im = Image.open(BytesIO(image_bytes))
+    imgs = [frame.copy() for frame in ImageSequence.Iterator(im)]
+    return imgs[1:]
 
 
 def load_image(path, resize_height, resize_width, gray, normalization):
