@@ -43,7 +43,7 @@ def get_args_parser():
     parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + __version__)
     parser.add_argument('-e', '--env', type=str, required=True, default='local', help='local/online')
     parser.add_argument('-f', '--file', type=str, default='', help='custom file path')
-    parser.add_argument('-F', '--force', action="store_false", default=False, help='remove exist files')
+    parser.add_argument('-F', '--force', action="store_true", default=False, help='remove exist files')
     return parser
 
 
